@@ -1,27 +1,15 @@
 require 'inputDataModel'
 require 'const'
 require 'outgoModel'
-if RUBY_PLATFORM.include?(Const::MACOS) then
-	require 'uconv'
-elsif RUBY_PLATFORM.include?(Const::MSWIN) then
-	require 'kconv'
-end
+require 'kconv'
 
 class KanjiConv
 	def KanjiConv.to_euc(str)
-		if RUBY_PLATFORM.include?(Const::MACOS) then
-			return Uconv.u8toeuc(str)
-		elsif RUBY_PLATFORM.include?(Const::MSWIN) then
-			return Kconv.toeuc(str)
-		end
+		return Kconv.toeuc(str)
 	end
 
 	def KanjiConv.to_utf8(str)
-		if RUBY_PLATFORM.include?(Const::MACOS) then
-			return Uconv.euctou8(str)
-		elsif RUBY_PLATFORM.include?(Const::MSWIN) then
-			return Kconv.toutf8(str)
-		end
+		return Kconv.toutf8(str)
 	end
 end
 
